class Resource:
    def resources(self):
        return []

    def permissions(self):
        return []

    def variables(self):
        return {}
